import sensors from './sensorsdata.es6.min.js'
// AZ 功能支付结果，，暂定服务端埋点
// export const FunctionPayResult = ({is_success,fail_reason=''})=>{
//   sensors.track('FunctionPayResult', {
//     is_success, // 布尔值
//     fail_reason, // 失败原因，选填，支付成功不填写
//   });
// }


/**
 * AZ, 进入医生问诊页面,进入医生问诊页时触发（注：30分钟内反复进入仅记录第一次）
 * @param {diagnosis_function_name} 判断从哪个功能过来的（快速问诊、报告解读、专家在线、在线开药、AZ问诊开药-血脂、AZ问诊开药-幽门）
 * @param {hospital_order_id} 互医订单ID
 * @param {doctor_id} 医生ID
 * @param {doctor_name} 医生名称
 */
export const OnlineDiagnosis = ({ diagnosis_function_name, hospital_order_id = '', doctor_id, doctor_name }) => {
  sensors.track('OnlineDiagnosis', {
    diagnosis_function_name,
    hospital_order_id,
    doctor_id,
    doctor_name
  });
}

/**
 * AZ开药问诊，点击【立即咨询】时触发
 * @param {az_consult_type} 咨询类型，血脂异常、幽门螺旋杆菌
 */
export const AZConsultClick = ({ az_consult_type }) => {
  sensors.track('AZConsultClick', {
    az_consult_type,
  });
}


/**
 * 医生发送处方成功后触发
 * @param {is_success} 开具处方成功还是失败，布尔值
 * @param {fail_reason} 失败原因，选填
 */
export const PrescriptionResult = ({ is_success, fail_reason = '' }) => {
  sensors.track('PrescriptionResult', {
    is_success,
    fail_reason
  });
}

/**
 * h5电商平台
 * 商城首页浏览
 */
 export const MallView = () => {
  sensors.track('MallView');
}

/**
 * h5电商平台
 * 商城列表页浏览
 * @param {section_name} 专区名称
 * @param {list_name} 品类名称
 */
 export const CommodityListView = ({section_name, list_name}) => {
  sensors.track('CommodityListView', {
    section_name,
    list_name
  });
}

/**
 * h5电商平台
 * 商城Icon点击
 * @param {page_type} 页面类型
 * @param {section_name} 专区名称
 * @param {list_name} 品类名称
 */
 export const MallIconClick = ({page_type, section_name, list_name}) => {
  sensors.track('MallIconClick', {
    page_type,
    section_name,
    list_name
  });
}

/**
 * h5电商平台
 * 浏览商品详情页
 * @param {page_source} 页面来源
 * @param {commodity_id} 商品ID
 * @param {commodity_name} 商品名称
 * @param {commodity_type} 商品类型
 * @param {first_category} 商品一级分类
 * @param {second_category} 商品二级分类
 * @param {original_price} 商品原价 
 * @param {present_price} 商品现价
 * @param {brand_name} 品牌名称
 * @param {dealer_id} 经销商ID
 * @param {dealer_name} 经销商名称
 * @param {promotion_type} 活动类型
 * @param {promotion_id} 活动ID
 * @param {promotion_name} 活动名称
 */
 export const CommodityView = ({page_source, commodity_id, commodity_name, commodity_type,
   first_category, second_category, original_price, present_price, brand_name, dealer_id, dealer_name, 
   promotion_type, promotion_id, promotion_name}) => {
  sensors.track('CommodityView', {
    page_source, commodity_id, commodity_name, commodity_type, first_category, second_category,
    original_price, present_price, brand_name, dealer_id, dealer_name, promotion_type, promotion_id, promotion_name
  });
}

/**
 * h5电商平台
 * 立即购买
 * @param {commodity_id} 商品ID
 * @param {commodity_name} 商品名称
 * @param {commodity_type} 商品类型
 * @param {first_category} 商品一级分类
 * @param {second_category} 商品二级分类
 * @param {original_price} 商品原价 
 * @param {present_price} 商品现价
 * @param {brand_name} 品牌名称
 * @param {dealer_id} 经销商ID
 * @param {dealer_name} 经销商名称
 * @param {commodity_quantity} 商品数量
 */
 export const BuyNow = ({commodity_id, commodity_name, commodity_type,first_category, second_category,
   original_price, present_price, brand_name, dealer_id, dealer_name, commodity_quantity}) => {
 sensors.track('BuyNow', {
   commodity_id, commodity_name, commodity_type, first_category, second_category,
   original_price, present_price, brand_name, dealer_id, dealer_name, commodity_quantity
 });
}

/**
 * h5电商平台
 * 加入购物车
 * @param {commodity_id} 商品ID
 * @param {commodity_name} 商品名称
 * @param {commodity_type} 商品类型
 * @param {first_category} 商品一级分类
 * @param {second_category} 商品二级分类
 * @param {original_price} 商品原价 
 * @param {present_price} 商品现价
 * @param {brand_name} 品牌名称
 * @param {dealer_id} 经销商ID
 * @param {dealer_name} 经销商名称
 * @param {commodity_quantity} 商品数量
 */
 export const AddToShoppingCart = ({commodity_id, commodity_name, commodity_type,first_category, second_category,
  original_price, present_price, brand_name, dealer_id, dealer_name, commodity_quantity}) => {
sensors.track('AddToShoppingCart', {
  commodity_id, commodity_name, commodity_type, first_category, second_category,
  original_price, present_price, brand_name, dealer_id, dealer_name, commodity_quantity
});
}

/**
 * h5电商平台
 * 弹窗点击
 * @param {popup_name} 弹窗名称 default value 领取大礼包
 * @param {popup_id} 弹窗ID
 * @param {click_action} 点击动作
 */
 export const PopupClick = ({popup_name, popup_id, click_action}) => {
  sensors.track('PopupClick', {
    popup_name: popup_name || '领取大礼包',
    popup_id,
    click_action
  });
}

/**
 * h5电商平台
 * 领取优惠券
 * @param {page_type} 页面类型
 * @param {coupon_id} 优惠券ID
 * @param {promotion_name} 优惠券名称
 * @param {coupon_amount} number 优惠券金额
 * @param {coupon_type} 优惠券类型
 */
 export const ReceiveCoupon = ({page_type, coupon_id, coupon_name, coupon_amount, coupon_type}) => {
  sensors.track('ReceiveCoupon', {
    page_type,
    coupon_id,
    coupon_name,
    coupon_amount,
    coupon_type
  });
}

/**
 * h5电商平台
 * 活动页面浏览
 * @param {promotion_type} 活动类型
 * @param {promotion_id} 活动ID
 * @param {promotion_name} 活动名称
 */
 export const PromotionPage = ({promotion_type, promotion_id, promotion_name}) => {
  sensors.track('PromotionPage', {
    promotion_type,
    promotion_id,
    promotion_name
  });
}

/**
 * h5电商平台
 * 运营位点击
 * @param {page_type} 页面类型
 * @param {banner_belong_area} 版区
 * @param {banner_type} 类型
 * @param {banner_name} 名称
 * @param {banner_id} number ID
 * @param {url} url
 * @param {banner_rank} number 排序
 */
 export const BannerClick = ({page_type, banner_belong_area, banner_type, banner_name, banner_id, url, banner_rank}) => {
  sensors.track('BannerClick', {
    page_type,
    banner_belong_area,
    banner_type,
    banner_name,
    banner_id,
    url,
    banner_rank
  });
}

/**
 * 神策登录
 * @param {userId} string 用户唯一标识
 * @param {gender} string 男 女
 * @param {year_of_birth} number 出生年份,例如 1996
 * @param {country} string 国家,例如 中国
 * @param {province} string 省份,例如 安徽
 * @param {city} string 城市,例如 上海，深圳
 * @param {createDate} DATETIME 注册时间,例如 2021-07-01 18:21:30
 * @param {first_order_time} DATETIME 首次下单时间,例如 2021-07-01 18:21:30
 * @param {last_order_time} DATETIME 最近下单时间,例如 2021-07-01 18:21:30
 */
export const login = ({userId, gender, year_of_birth, country, province, city, createDate, first_order_time, last_order_time }) => {
  sensors.login(userId)
  // sensors.setProfile({ gender: '' });
  sensors.setProfile({ register_time: createDate });
}
